@@ -15,7 +15,8 @@ class IAMTrustedEntities(BaseBalconyApp,
     
     def __init__(self, *args, **kwargs) -> None:
         # super(BaseBalconyApp, self).__init__(*args, **kwargs)
-        print('MyApp initialized.')
+        # print('MyApp initialized.')
+        pass
       
     def get_data(self, *args, **kwargs) -> dict:
         balcony = BalconyAWS()
